==> arrow-instances-free-0.8.0-sources.jar: extension/arrow/free/instances/freeapplicative/functor/FreeApplicativeFunctorInstance.kt <==
package arrow.free.instances.freeapplicative.functor

import arrow.Kind
import arrow.core.Tuple2
import arrow.free.ForFreeApplicative
import arrow.free.FreeApplicative
import arrow.free.FreeApplicative.Companion
import arrow.free.instances.FreeApplicativeFunctorInstance
import kotlin.Function1
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.map(arg1: Function1<A, B>): FreeApplicative<S, B> = arrow.free.FreeApplicative.functor<S>().run {
  this@map.map<A, B>(arg1) as arrow.free.FreeApplicative<S, B>
}

@JvmName("imap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): FreeApplicative<S, B> = arrow.free.FreeApplicative.functor<S>().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.free.FreeApplicative<S, B>
}

@JvmName("lift")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> lift(arg0: Function1<A, B>): Function1<Kind<Kind<ForFreeApplicative, S>, A>, Kind<Kind<ForFreeApplicative, S>, B>> = arrow.free.FreeApplicative
   .functor<S>()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.Kind<arrow.free.ForFreeApplicative, S>, A>, arrow.Kind<arrow.Kind<arrow.free.ForFreeApplicative, S>, B>>

@JvmName("void")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A> Kind<Kind<ForFreeApplicative, S>, A>.void(): FreeApplicative<S, Unit> = arrow.free.FreeApplicative.functor<S>().run {
  this@void.void<A>() as arrow.free.FreeApplicative<S, kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.fproduct(arg1: Function1<A, B>): FreeApplicative<S, Tuple2<A, B>> = arrow.free.FreeApplicative.functor<S>().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.free.FreeApplicative<S, arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.`as`(arg1: B): FreeApplicative<S, B> = arrow.free.FreeApplicative.functor<S>().run {
  this@`as`.`as`<A, B>(arg1) as arrow.free.FreeApplicative<S, B>
}

@JvmName("tupleLeft")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.tupleLeft(arg1: B): FreeApplicative<S, Tuple2<B, A>> = arrow.free.FreeApplicative.functor<S>().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.free.FreeApplicative<S, arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.tupleRight(arg1: B): FreeApplicative<S, Tuple2<A, B>> = arrow.free.FreeApplicative.functor<S>().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.free.FreeApplicative<S, arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B, A : B> Kind<Kind<ForFreeApplicative, S>, A>.widen(): FreeApplicative<S, B> = arrow.free.FreeApplicative.functor<S>().run {
  this@widen.widen<B, A>() as arrow.free.FreeApplicative<S, B>
}

fun <S> Companion.functor(): FreeApplicativeFunctorInstance<S> = object : arrow.free.instances.FreeApplicativeFunctorInstance<S> {  }

==> arrow-instances-free-0.8.2-sources.jar: extension/arrow/free/instances/freeapplicative/functor/FreeApplicativeFunctorInstance.kt <==
package arrow.free.instances.freeapplicative.functor

import arrow.Kind
import arrow.core.Tuple2
import arrow.free.ForFreeApplicative
import arrow.free.FreeApplicative
import arrow.free.FreeApplicative.Companion
import arrow.free.instances.FreeApplicativeFunctorInstance
import kotlin.Function1
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.map(arg1: Function1<A, B>): FreeApplicative<S, B> = arrow.free.FreeApplicative.functor<S>().run {
  this@map.map<A, B>(arg1) as arrow.free.FreeApplicative<S, B>
}

@JvmName("imap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): FreeApplicative<S, B> = arrow.free.FreeApplicative.functor<S>().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.free.FreeApplicative<S, B>
}

@JvmName("lift")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> lift(arg0: Function1<A, B>): Function1<Kind<Kind<ForFreeApplicative, S>, A>, Kind<Kind<ForFreeApplicative, S>, B>> = arrow.free.FreeApplicative
   .functor<S>()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.Kind<arrow.free.ForFreeApplicative, S>, A>, arrow.Kind<arrow.Kind<arrow.free.ForFreeApplicative, S>, B>>

@JvmName("unit")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A> Kind<Kind<ForFreeApplicative, S>, A>.unit(): FreeApplicative<S, Unit> = arrow.free.FreeApplicative.functor<S>().run {
  this@unit.unit<A>() as arrow.free.FreeApplicative<S, kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.fproduct(arg1: Function1<A, B>): FreeApplicative<S, Tuple2<A, B>> = arrow.free.FreeApplicative.functor<S>().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.free.FreeApplicative<S, arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.`as`(arg1: B): FreeApplicative<S, B> = arrow.free.FreeApplicative.functor<S>().run {
  this@`as`.`as`<A, B>(arg1) as arrow.free.FreeApplicative<S, B>
}

@JvmName("tupleLeft")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.tupleLeft(arg1: B): FreeApplicative<S, Tuple2<B, A>> = arrow.free.FreeApplicative.functor<S>().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.free.FreeApplicative<S, arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFreeApplicative, S>, A>.tupleRight(arg1: B): FreeApplicative<S, Tuple2<A, B>> = arrow.free.FreeApplicative.functor<S>().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.free.FreeApplicative<S, arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B, A : B> Kind<Kind<ForFreeApplicative, S>, A>.widen(): FreeApplicative<S, B> = arrow.free.FreeApplicative.functor<S>().run {
  this@widen.widen<B, A>() as arrow.free.FreeApplicative<S, B>
}

fun <S> Companion.functor(): FreeApplicativeFunctorInstance<S> = object : arrow.free.instances.FreeApplicativeFunctorInstance<S> {  }
